﻿namespace UltraGridSample.DataModels
{
    using System;
    using System.ComponentModel;
    using System.Runtime.CompilerServices;

    public class Product : INotifyPropertyChanged
    {
        private int id;
        private string productName = string.Empty;


        public event PropertyChangedEventHandler PropertyChanged;

        // This method is called by the Set accessor of each property.
        // The CallerMemberName attribute that is applied to the optional propertyName
        // parameter causes the property name of the caller to be substituted as an argument.
        private void NotifyPropertyChanged([CallerMemberName] string propertyName = "")
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }

        public int Id
        {
            get
            {
                return this.id;
            }

            set
            {
                if (id != value)
                {
                    if (this.id >= 0)
                    {
                        this.id = value;
                        NotifyPropertyChanged();
                    }
                    else
                    {
                        throw new ArgumentException("Id cannot be a negative number!");
                    }
                }
            }
        }

        public string ProductName
        {
            get
            {
                return this.productName;
            }

            set
            {
                if (this.productName != value)
                {
                    this.productName = value;
                    NotifyPropertyChanged();
                }
            }
        }
    }
}
